==> mingw-w64-clang-aarch64-vtk-9.3.1-1-any.pkg.tar.zst: clangarm64/lib/python3.11/site-packages/vtk.py <==
"""This is the vtk module"""

# this module has the same contents as vtkmodules.all
from vtkmodules.vtkCommonCore import *
from vtkmodules.vtkCommonMath import *
from vtkmodules.vtkCommonTransforms import *
from vtkmodules.vtkCommonDataModel import *
from vtkmodules.vtkCommonExecutionModel import *
from vtkmodules.vtkCommonMisc import *
from vtkmodules.vtkFiltersCore import *
from vtkmodules.vtkRenderingCore import *
from vtkmodules.vtkFiltersGeneral import *
from vtkmodules.vtkImagingCore import *
from vtkmodules.vtkIOImage import *
from vtkmodules.vtkRenderingHyperTreeGrid import *
from vtkmodules.vtkRenderingUI import *
from vtkmodules.vtkRenderingOpenGL2 import *
from vtkmodules.vtkFiltersSources import *
from vtkmodules.vtkRenderingContext2D import *
from vtkmodules.vtkInteractionWidgets import *
from vtkmodules.vtkViewsCore import *
from vtkmodules.vtkInteractionStyle import *
from vtkmodules.vtkViewsInfovis import *
from vtkmodules.vtkCommonComputationalGeometry import *
from vtkmodules.vtkCommonSystem import *
from vtkmodules.vtkIOCore import *
from vtkmodules.vtkIOLegacy import *
from vtkmodules.vtkIOXMLParser import *
from vtkmodules.vtkDomainsChemistry import *
from vtkmodules.vtkRenderingFreeType import *
from vtkmodules.vtkRenderingContextOpenGL2 import *
from vtkmodules.vtkRenderingVolume import *
from vtkmodules.vtkImagingMath import *
from vtkmodules.vtkRenderingVolumeOpenGL2 import *
from vtkmodules.vtkViewsContext2D import *
from vtkmodules.vtkTestingRendering import *
from vtkmodules.vtkRenderingSceneGraph import *
from vtkmodules.vtkRenderingRayTracing import *
from vtkmodules.vtkRenderingVolumeAMR import *
from vtkmodules.vtkRenderingLabel import *
from vtkmodules.vtkRenderingQt import *
from vtkmodules.vtkPythonContext2D import *
from vtkmodules.vtkRenderingParallel import *
from vtkmodules.vtkRenderingVR import *
from vtkmodules.vtkRenderingOpenXR import *
from vtkmodules.vtkRenderingOpenVR import *
from vtkmodules.vtkRenderingMatplotlib import *
from vtkmodules.vtkRenderingLOD import *
from vtkmodules.vtkRenderingLICOpenGL2 import *
from vtkmodules.vtkRenderingImage import *
from vtkmodules.vtkIOMovie import *
from vtkmodules.vtkIOVideo import *
from vtkmodules.vtkIOFFMPEG import *
from vtkmodules.vtkRenderingFFMPEGOpenGL2 import *
from vtkmodules.vtkRenderingExternal import *
from vtkmodules.vtkFiltersCellGrid import *
from vtkmodules.vtkRenderingCellGrid import *
from vtkmodules.vtkIOXdmf2 import *
from vtkmodules.vtkIOVeraOut import *
from vtkmodules.vtkIOVPIC import *
from vtkmodules.vtkIOTecplotTable import *
from vtkmodules.vtkIOTRUCHAS import *
from vtkmodules.vtkIOSegY import *
from vtkmodules.vtkIOSQL import *
from vtkmodules.vtkIOPostgreSQL import *
from vtkmodules.vtkIOXdmf3 import *
from vtkmodules.vtkIOXML import *
from vtkmodules.vtkIOParallelXML import *
from vtkmodules.vtkIOLSDyna import *
from vtkmodules.vtkIOParallelLSDyna import *
from vtkmodules.vtkIOExodus import *
from vtkmodules.vtkIOParallelExodus import *
from vtkmodules.vtkIOGeometry import *
from vtkmodules.vtkIOParallel import *
from vtkmodules.vtkIOPLY import *
from vtkmodules.vtkIOPIO import *
from vtkmodules.vtkIOPDAL import *
from vtkmodules.vtkIOOpenVDB import *
from vtkmodules.vtkIOOggTheora import *
from vtkmodules.vtkIOOMF import *
from vtkmodules.vtkIOODBC import *
from vtkmodules.vtkIOOCCT import *
from vtkmodules.vtkIONetCDF import *
from vtkmodules.vtkIOMySQL import *
from vtkmodules.vtkIOMotionFX import *
from vtkmodules.vtkIOMINC import *
from vtkmodules.vtkIOLAS import *
from vtkmodules.vtkIOInfovis import *
from vtkmodules.vtkIOImport import *
from vtkmodules.vtkParallelCore import *
from vtkmodules.vtkIOIOSS import *
from vtkmodules.vtkIOH5part import *
from vtkmodules.vtkIOH5Rage import *
from vtkmodules.vtkIOGeoJSON import *
from vtkmodules.vtkIOFides import *
from vtkmodules.vtkIOFLUENTCFF import *
from vtkmodules.vtkRenderingVtkJS import *
from vtkmodules.vtkIOExport import *
from vtkmodules.vtkIOExportPDF import *
from vtkmodules.vtkRenderingGL2PSOpenGL2 import *
from vtkmodules.vtkIOExportGL2PS import *
from vtkmodules.vtkIOEnSight import *
from vtkmodules.vtkIOCityGML import *
from vtkmodules.vtkIOChemistry import *
from vtkmodules.vtkIOCesium3DTiles import *
from vtkmodules.vtkIOCellGrid import *
from vtkmodules.vtkIOCONVERGECFD import *
from vtkmodules.vtkIOHDF import *
from vtkmodules.vtkIOCGNSReader import *
from vtkmodules.vtkIOAsynchronous import *
from vtkmodules.vtkIOAMR import *
from vtkmodules.vtkIOADIOS2 import *
from vtkmodules.vtkInteractionImage import *
from vtkmodules.vtkInfovisBoostGraphAlgorithms import *
from vtkmodules.vtkImagingStencil import *
from vtkmodules.vtkImagingStatistics import *
from vtkmodules.vtkImagingGeneral import *
from vtkmodules.vtkImagingOpenGL2 import *
from vtkmodules.vtkImagingMorphological import *
from vtkmodules.vtkImagingFourier import *
from vtkmodules.vtkIOGDAL import *
from vtkmodules.vtkGeovisGDAL import *
from vtkmodules.vtkCommonColor import *
from vtkmodules.vtkImagingSources import *
from vtkmodules.vtkInfovisCore import *
from vtkmodules.vtkGeovisCore import *
from vtkmodules.vtkInfovisLayout import *
from vtkmodules.vtkRenderingAnnotation import *
from vtkmodules.vtkImagingHybrid import *
from vtkmodules.vtkImagingColor import *
from vtkmodules.vtkFiltersTopology import *
from vtkmodules.vtkFiltersTensor import *
from vtkmodules.vtkFiltersSelection import *
from vtkmodules.vtkFiltersSMP import *
from vtkmodules.vtkFiltersReebGraph import *
from vtkmodules.vtkFiltersReduction import *
from vtkmodules.vtkFiltersPython import *
from vtkmodules.vtkFiltersProgrammable import *
from vtkmodules.vtkFiltersModeling import *
from vtkmodules.vtkFiltersPoints import *
from vtkmodules.vtkFiltersStatistics import *
from vtkmodules.vtkFiltersParallelStatistics import *
from vtkmodules.vtkFiltersImaging import *
from vtkmodules.vtkFiltersExtraction import *
from vtkmodules.vtkFiltersGeometry import *
from vtkmodules.vtkFiltersHybrid import *
from vtkmodules.vtkFiltersHyperTree import *
from vtkmodules.vtkFiltersTexture import *
from vtkmodules.vtkFiltersParallel import *
from vtkmodules.vtkFiltersParallelImaging import *
from vtkmodules.vtkFiltersParallelDIY2 import *
from vtkmodules.vtkChartsCore import *
from vtkmodules.vtkFiltersOpenTURNS import *
from vtkmodules.vtkFiltersGeometryPreview import *
from vtkmodules.vtkFiltersGeneric import *
from vtkmodules.vtkFiltersFlowPaths import *
from vtkmodules.vtkFiltersAMR import *
from vtkmodules.vtkDomainsMicroscopy import *
from vtkmodules.vtkDomainsChemistryOpenGL2 import *
from vtkmodules.vtkCommonPython import *
from vtkmodules.vtkCommonArchive import *
from vtkmodules.vtkAcceleratorsVTKmCore import *
from vtkmodules.vtkAcceleratorsVTKmDataModel import *
from vtkmodules.vtkAcceleratorsVTKmFilters import *
from vtkmodules.vtkFiltersVerdict import *


# useful macro for getting type names
from vtkmodules.util.vtkConstants import vtkImageScalarTypeNameMacro

# import convenience decorators
from vtkmodules.util.misc import calldata_type

# import the vtkVariant helpers
from vtkmodules.util.vtkVariant import *

# clone parts of vtkmodules to make this look like a package
import vtkmodules as _vtk_package
__path__ = _vtk_package.__path__
__version__ = _vtk_package.__version__
del _vtk_package

==> mingw-w64-clang-aarch64-vtk-9.5.2-5-any.pkg.tar.zst: clangarm64/lib/python3.12/site-packages/vtk.py <==
"""This is the vtk module"""

# this module has the same contents as vtkmodules.all
from vtkmodules.vtkCommonCore import *
from vtkmodules.vtkCommonMath import *
from vtkmodules.vtkCommonTransforms import *
from vtkmodules.vtkCommonDataModel import *
from vtkmodules.vtkCommonExecutionModel import *
from vtkmodules.vtkCommonMisc import *
from vtkmodules.vtkFiltersCore import *
from vtkmodules.vtkRenderingCore import *
from vtkmodules.vtkFiltersGeneral import *
from vtkmodules.vtkImagingCore import *
from vtkmodules.vtkIOImage import *
from vtkmodules.vtkRenderingHyperTreeGrid import *
from vtkmodules.vtkRenderingUI import *
from vtkmodules.vtkRenderingOpenGL2 import *
from vtkmodules.vtkFiltersSources import *
from vtkmodules.vtkRenderingContext2D import *
from vtkmodules.vtkInteractionWidgets import *
from vtkmodules.vtkViewsCore import *
from vtkmodules.vtkInteractionStyle import *
from vtkmodules.vtkViewsInfovis import *
from vtkmodules.vtkCommonComputationalGeometry import *
from vtkmodules.vtkCommonSystem import *
from vtkmodules.vtkIOCore import *
from vtkmodules.vtkFiltersCellGrid import *
from vtkmodules.vtkIOCellGrid import *
from vtkmodules.vtkIOLegacy import *
from vtkmodules.vtkIOXMLParser import *
from vtkmodules.vtkDomainsChemistry import *
from vtkmodules.vtkRenderingFreeType import *
from vtkmodules.vtkRenderingContextOpenGL2 import *
from vtkmodules.vtkRenderingVolume import *
from vtkmodules.vtkImagingMath import *
from vtkmodules.vtkRenderingVolumeOpenGL2 import *
from vtkmodules.vtkViewsContext2D import *
from vtkmodules.vtkImagingColor import *
from vtkmodules.vtkIOXML import *
from vtkmodules.vtkTestingRendering import *
from vtkmodules.vtkRenderingSceneGraph import *
from vtkmodules.vtkRenderingRayTracing import *
from vtkmodules.vtkRenderingVolumeAMR import *
from vtkmodules.vtkRenderingLabel import *
from vtkmodules.vtkRenderingQt import *
from vtkmodules.vtkPythonContext2D import *
from vtkmodules.vtkParallelCore import *
from vtkmodules.vtkRenderingParallel import *
from vtkmodules.vtkRenderingVRModels import *
from vtkmodules.vtkRenderingVR import *
from vtkmodules.vtkRenderingOpenXR import *
from vtkmodules.vtkRenderingOpenVR import *
from vtkmodules.vtkRenderingMatplotlib import *
from vtkmodules.vtkRenderingLOD import *
from vtkmodules.vtkRenderingLICOpenGL2 import *
from vtkmodules.vtkRenderingImage import *
from vtkmodules.vtkChartsCore import *
from vtkmodules.vtkRenderingGridAxes import *
from vtkmodules.vtkIOMovie import *
from vtkmodules.vtkIOVideo import *
from vtkmodules.vtkIOFFMPEG import *
from vtkmodules.vtkRenderingFFMPEGOpenGL2 import *
from vtkmodules.vtkRenderingExternal import *
from vtkmodules.vtkRenderingCellGrid import *
from vtkmodules.vtkRenderingAnari import *
from vtkmodules.vtkIOXdmf2 import *
from vtkmodules.vtkIOVeraOut import *
from vtkmodules.vtkIOVPIC import *
from vtkmodules.vtkIOTecplotTable import *
from vtkmodules.vtkIOTRUCHAS import *
from vtkmodules.vtkIOSegY import *
from vtkmodules.vtkIOSQL import *
from vtkmodules.vtkIOPostgreSQL import *
from vtkmodules.vtkIOXdmf3 import *
from vtkmodules.vtkIOParallelXML import *
from vtkmodules.vtkIOLSDyna import *
from vtkmodules.vtkIOParallelLSDyna import *
from vtkmodules.vtkIOExodus import *
from vtkmodules.vtkIOParallelExodus import *
from vtkmodules.vtkIOGeometry import *
from vtkmodules.vtkIOParallel import *
from vtkmodules.vtkIOPLY import *
from vtkmodules.vtkIOPIO import *
from vtkmodules.vtkIOPDAL import *
from vtkmodules.vtkIOOpenVDB import *
from vtkmodules.vtkIOOggTheora import *
from vtkmodules.vtkIOOMF import *
from vtkmodules.vtkIOODBC import *
from vtkmodules.vtkIOOCCT import *
from vtkmodules.vtkIONetCDF import *
from vtkmodules.vtkIOMySQL import *
from vtkmodules.vtkIOMotionFX import *
from vtkmodules.vtkIOMINC import *
from vtkmodules.vtkIOLAS import *
from vtkmodules.vtkIOLANLX3D import *
from vtkmodules.vtkIOImport import *
from vtkmodules.vtkIOIOSS import *
from vtkmodules.vtkIOHDF import *
from vtkmodules.vtkIOH5part import *
from vtkmodules.vtkIOH5Rage import *
from vtkmodules.vtkIOGeoJSON import *
from vtkmodules.vtkIOFides import *
from vtkmodules.vtkIOFLUENTCFF import *
from vtkmodules.vtkIOFDS import *
from vtkmodules.vtkIOInfovis import *
from vtkmodules.vtkRenderingVtkJS import *
from vtkmodules.vtkIOExport import *
from vtkmodules.vtkIOExportPDF import *
from vtkmodules.vtkRenderingGL2PSOpenGL2 import *
from vtkmodules.vtkIOExportGL2PS import *
from vtkmodules.vtkIOEngys import *
from vtkmodules.vtkIOEnSight import *
from vtkmodules.vtkIOERF import *
from vtkmodules.vtkIOCityGML import *
from vtkmodules.vtkIOChemistry import *
from vtkmodules.vtkIOCesium3DTiles import *
from vtkmodules.vtkIOCONVERGECFD import *
from vtkmodules.vtkIOCGNSReader import *
from vtkmodules.vtkIOAvmesh import *
from vtkmodules.vtkIOAsynchronous import *
from vtkmodules.vtkIOAlembic import *
from vtkmodules.vtkIOAMR import *
from vtkmodules.vtkIOADIOS2 import *
from vtkmodules.vtkInteractionImage import *
from vtkmodules.vtkInfovisLayout import *
from vtkmodules.vtkInfovisBoostGraphAlgorithms import *
from vtkmodules.vtkImagingStencil import *
from vtkmodules.vtkImagingStatistics import *
from vtkmodules.vtkImagingGeneral import *
from vtkmodules.vtkImagingOpenGL2 import *
from vtkmodules.vtkImagingMorphological import *
from vtkmodules.vtkImagingFourier import *
from vtkmodules.vtkRenderingAnnotation import *
from vtkmodules.vtkImagingHybrid import *
from vtkmodules.vtkIOGDAL import *
from vtkmodules.vtkGeovisGDAL import *
from vtkmodules.vtkGeovisCore import *
from vtkmodules.vtkFiltersTopology import *
from vtkmodules.vtkFiltersTensor import *
from vtkmodules.vtkFiltersSelection import *
from vtkmodules.vtkFiltersSMP import *
from vtkmodules.vtkFiltersReebGraph import *
from vtkmodules.vtkFiltersPython import *
from vtkmodules.vtkFiltersProgrammable import *
from vtkmodules.vtkFiltersModeling import *
from vtkmodules.vtkFiltersPoints import *
from vtkmodules.vtkFiltersVerdict import *
from vtkmodules.vtkFiltersParallelVerdict import *
from vtkmodules.vtkFiltersStatistics import *
from vtkmodules.vtkFiltersParallelStatistics import *
from vtkmodules.vtkFiltersImaging import *
from vtkmodules.vtkFiltersExtraction import *
from vtkmodules.vtkFiltersGeometry import *
from vtkmodules.vtkFiltersHybrid import *
from vtkmodules.vtkFiltersHyperTree import *
from vtkmodules.vtkFiltersTexture import *
from vtkmodules.vtkFiltersParallel import *
from vtkmodules.vtkFiltersParallelImaging import *
from vtkmodules.vtkFiltersParallelDIY2 import *
from vtkmodules.vtkFiltersTemporal import *
from vtkmodules.vtkFiltersOpenTURNS import *
from vtkmodules.vtkFiltersGeometryPreview import *
from vtkmodules.vtkFiltersGeneric import *
from vtkmodules.vtkFiltersFlowPaths import *
from vtkmodules.vtkFiltersAMR import *
from vtkmodules.vtkDomainsMicroscopy import *
from vtkmodules.vtkDomainsChemistryOpenGL2 import *
from vtkmodules.vtkCommonPython import *
from vtkmodules.vtkCommonArchive import *
from vtkmodules.vtkCommonColor import *
from vtkmodules.vtkImagingSources import *
from vtkmodules.vtkInfovisCore import *
from vtkmodules.vtkAcceleratorsVTKmCore import *
from vtkmodules.vtkAcceleratorsVTKmDataModel import *
from vtkmodules.vtkAcceleratorsVTKmFilters import *
from vtkmodules.vtkFiltersReduction import *


# useful macro for getting type names
from vtkmodules.util.vtkConstants import vtkImageScalarTypeNameMacro

# import convenience decorators
from vtkmodules.util.misc import calldata_type

# import the vtkVariant helpers
from vtkmodules.util.vtkVariant import *

# clone parts of vtkmodules to make this look like a package
import vtkmodules as _vtk_package
__path__ = _vtk_package.__path__
__version__ = _vtk_package.__version__
del _vtk_package
